# ModelProperty

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**definition** | [**PropertyDefinition**](PropertyDefinition.md) |  | 
**value** | [**object**](.md) |  | [optional] 
**property_set_id** | **str** | This field is useful when you update a property and the  API is rebuilding a new property set to avoid an update on many elements. It gives you the new pset id | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


